All of lore.kernel.org
 help / color / mirror / Atom feed
From: Malcolm Priestley <tvboxspy@gmail.com>
To: gregkh@linuxfoundation.org
Cc: linux-wireless@vger.kernel.org, Malcolm Priestley <tvboxspy@gmail.com>
Subject: [PATCH 03/12] staging: vt6656: rename device_free_tx_bufs to vnt_free_tx_bufs
Date: Fri, 25 Jul 2014 20:51:47 +0100	[thread overview]
Message-ID: <1406317916-21884-3-git-send-email-tvboxspy@gmail.com> (raw)
In-Reply-To: <1406317916-21884-1-git-send-email-tvboxspy@gmail.com>

changing device to vnt

Signed-off-by: Malcolm Priestley <tvboxspy@gmail.com>
---
 drivers/staging/vt6656/main_usb.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/drivers/staging/vt6656/main_usb.c b/drivers/staging/vt6656/main_usb.c
index 51fad26..88484c8 100644
--- a/drivers/staging/vt6656/main_usb.c
+++ b/drivers/staging/vt6656/main_usb.c
@@ -34,7 +34,7 @@
  *   device_ioctl - ioctl entry
  *   device_close - shutdown mac/bbp & free dma/descriptor resource
  *   device_alloc_frag_buf - rx fragement pre-allocated function
  *   device_free_tx_bufs - free tx buffer function
  *   device_dma0_tx_80211- tx 802.11 frame via dma0
  *   device_dma0_xmit- tx PS buffered frame via dma0
  *   vnt_init_registers- initial MAC & BBP & RF internal registers.
@@ -378,7 +378,7 @@ static int vnt_init_registers(struct vnt_private *priv)
 	return true;
 }
 
-static void device_free_tx_bufs(struct vnt_private *priv)
+static void vnt_free_tx_bufs(struct vnt_private *priv)
 {
 	struct vnt_usb_send_context *tx_context;
 	int ii;
@@ -521,7 +521,7 @@ free_rx_tx:
 	device_free_rx_bufs(priv);
 
 free_tx:
-	device_free_tx_bufs(priv);
+	vnt_free_tx_bufs(priv);
 
 	return false;
 }
@@ -568,7 +568,7 @@ static int vnt_start(struct ieee80211_hw *hw)
 
 free_all:
 	device_free_rx_bufs(priv);
-	device_free_tx_bufs(priv);
+	vnt_free_tx_bufs(priv);
 	device_free_int_bufs(priv);
 
 	usb_kill_urb(priv->interrupt_urb);
@@ -602,7 +602,7 @@ static void vnt_stop(struct ieee80211_hw *hw)
 
 	priv->cmd_running = false;
 
-	device_free_tx_bufs(priv);
+	vnt_free_tx_bufs(priv);
 	device_free_rx_bufs(priv);
 	device_free_int_bufs(priv);
 
@@ -34,7 +34,7 @@
  *   device_close - shutdown mac/bbp & free dma/descriptor resource
  *   device_alloc_frag_buf - rx fragement pre-allocated function
- *   device_free_tx_bufs - free tx buffer function
+ *   vnt_free_tx_bufs - free tx buffer function
  *   device_dma0_tx_80211- tx 802.11 frame via dma0
  *   device_dma0_xmit- tx PS buffered frame via dma0
-- 
2.0.1


  parent reply	other threads:[~2014-07-25 19:52 UTC|newest]

Thread overview: 12+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2014-07-25 19:51 [PATCH 01/12] staging: vt6656: rename device_set_options to vnt_set_options Malcolm Priestley
2014-07-25 19:51 ` [PATCH 02/12] staging: vt6656: rename device_init_registers to vnt_init_registers Malcolm Priestley
2014-07-25 19:51 ` Malcolm Priestley [this message]
2014-07-25 19:51 ` [PATCH 04/12] staging: vt6656: rename device_free_rx_bufs to vnt_free_rx_bufs Malcolm Priestley
2014-07-25 19:51 ` [PATCH 05/12] staging: vt6656: rename device_free_int_bufs to vnt_free_int_bufs Malcolm Priestley
2014-07-25 19:51 ` [PATCH 06/12] staging: vt6656: rename device_alloc_bufs to vnt_alloc_bufs Malcolm Priestley
2014-07-25 19:51 ` [PATCH 07/12] staging: vt6656: main_usb.c remove comments to functions nolonger present Malcolm Priestley
2014-07-25 19:51 ` [PATCH 08/12] staging: vt6656: change driver version to mac80211 Malcolm Priestley
2014-07-25 19:51 ` [PATCH 09/12] staging: vt6656: main_usb.c remove return from void functions Malcolm Priestley
2014-07-25 19:51 ` [PATCH 10/12] staging: vt6656: remove return from all " Malcolm Priestley
2014-07-25 19:51 ` [PATCH 11/12] staging: vt6656: remove comments of old functions nolonger present Malcolm Priestley
2014-07-25 19:51 ` [PATCH 12/12] staging: vt6656: rf.h clean up comments Malcolm Priestley

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1406317916-21884-3-git-send-email-tvboxspy@gmail.com \
    --to=tvboxspy@gmail.com \
    --cc=gregkh@linuxfoundation.org \
    --cc=linux-wireless@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.